# Space Diner

Space Diner is a sci-fi themed, text-based sim game. 
The player runs a diner that is visited by customers from our solar system and beyond! 
The goal is to serve each of them a meal that they like and that they can digest.
The player's activities include taking orders, buying ingredients, and cooking.
You can also get to know your regular customers and their stories.

## Installation

Python3 is required.

Install Space Diner with: `pip install space-diner`

[More detailed installation instructions are available here.](https://github.com/2e2a/space-diner/blob/master/INSTALL.md)

## Starting the game

Start the game with: `space-diner`

You can optionally start the game in a text-only mode (without decorative special characters): `space-diner --text-only`
